@@ -23,13 +23,16 @@
 skeletonplot <- function(x, skel.width = 100, skel.height = 200,
                          ylab = 'Height (cm)', base.radius = 2, xlab = '',
                          xlim = (nrow(x)*c(0,skel.width)), ylim = c(0, skel.height),
-                         col = c(hipbase = 1, hip = 1, shoulderbase = 1, shoulder = 1,
-                                 head = 1, elbow = 2, wrist = 3, knee = 4, ankle = 5,
-                                 chest = 'purple1', pelvis = 6),
-                         mtext = TRUE, skel.lwd = 1, ...) {
+                         col = NULL, mtext = TRUE, skel.lwd = 1, ...) {
 
   if ( is.data.frame(x) )
     x <- as.matrix(x)
+  
+  if ( is.null(col) ) {
+    col <- c(hipbase = 1, hip = 1, shoulderbase = 1, shoulder = 1,
+      head = 1, elbow = 2, wrist = 3, knee = 4, ankle = 5,
+      chest = 'purple1', pelvis = 6)
+  }
 
   ### Skeleton model (see human-modelling.vsd):
   model.y <- c(ankle=0, knee=7, wrist=12, hip=13, hipbase=15, pelvis=16,
